@@ -1,12 +1,14 @@
 #! /usr/bin/env python
 # -*- coding: utf-8 -*-
-"""Determine machine-specific parameters affecting floating-point arithmetic.
+"""
+Determine machine-specific parameters affecting floating-point
+arithmetic.
 
 Function to determine machine-specific parameters affecting
 floating-point arithmetic.
 
-This is build after "NUMERICAL RECIPES in C", second edition, Reprinted
-1996, pp. 889.
+* This is build after "NUMERICAL RECIPES in C", second edition,
+  Reprinted 1996, pp.  889.
 """
 
 from __future__ import division, print_function, absolute_import, unicode_literals
@@ -19,7 +21,7 @@ try:
 except ImportError:
     from backports.functools_lru_cache import lru_cache
 
-__date__ = "2020/04/26 00:17:50 hoel"
+__date__ = "2020/06/13 17:49:10 hoel"
 __author__ = "Berthold Höllmann"
 __copyright__ = "Copyright © 1999, 2000,2018 by Berthold Höllmann"
 __credits__ = ["Berthold Höllmann"]
@@ -32,53 +34,53 @@ def machar():
 Determines and returns machine-specific parameters affecting
 floating-point arithmetic. Returned values include:
 
-    'ibeta'  -- The radix in which numbers are represented, almost
-                always 2, but occasionally 16, or even 10
+    ``ibeta``  -- The radix in which numbers are represented, almost
+                  always 2, but occasionally 16, or even 10
 
-    'it'     -- The number of base-'ibeta' digits in the floating point
-                mantissa
+    ``it``     -- The number of base-``ibeta`` digits in the floating point
+                  mantissa
 
-    'machep' -- Is the exponent of the smallest (mos negative) power if
-                'ibeta' that, added to 1.0 gives something different
-                from 1.0.
+    ``machep`` -- Is the exponent of the smallest (mos negative) power if
+                  ``ibeta`` that, added to 1.0 gives something different
+                  from 1.0.
 
-    'eps'    -- Is the floating-point number 'ibeta'**'machdep', loosly
-                referred to as the ''floating-point precision.''
+    ``eps``    -- Is the floating-point number ``ibeta`` ** ``machdep``, loosly
+                  referred to as the *floating-point precision*.
 
-    'negep'  -- Is the exponenet of the smalles power of 'ibeta' that,
+    ``negep``  -- Is the exponenet of the smalles power of ``ibeta`` that,
                 subtracted from 1.0, gives something different from 1.0.
 
-    'epsneg' -- Is 'ibeta'**'negep', another way of defining
-                floating-point precision. Not infrequently 'epsneg' is
-                0.5 times 'eps'; occasionally 'eps' and 'epsneg' are
+    ``epsneg`` -- Is ``ibeta`` ** ``negep``, another way of defining
+                floating-point precision. Not infrequently ``epsneg`` is
+                0.5 times ``eps``; occasionally ``eps`` and ``epsneg`` are
                 equal.
 
-    'iexp'   -- Is the number of bits in the exponent (including its
+    ``iexp``   -- Is the number of bits in the exponent (including its
                 sign or bias)
 
-    'minexp' -- Is the smallest (most negative) power if 'ibeta'
+    ``minexp`` -- Is the smallest (most negative) power if ``ibeta``
                 consistent with there no leading zeros in the mantissa.
 
-    'xmin'   -- Is the floating-point number 'ibeta'**'minexp', generally
+    ``xmin``   -- Is the floating-point number ``ibeta`` ** ``minexp``, generally
                 the smallest (in magnitude) usable floating value
 
-    'maxexp' -- Is the smallest (positive) power of 'ibeta' that causes
+    ``maxexp`` -- Is the smallest (positive) power of ``ibeta`` that causes
                 overflow.
 
-    'xmax'   -- Is (1-'epsneg')x'ibeta'**'maxexp', generally the largest
+    ``xmax``   -- Is (1 - ``epsneg``) x ``ibeta`` ** ``maxexp``, generally the largest
                 (in magnitude) usable floating value.
 
-    'irnd'   -- Returns a code in the range 0...5, giving information on
+    ``irnd``   -- Returns a code in the range 0...5, giving information on
                 what kind of rounding is done in addition, and on how
                 underflow is handled.
 
-                If 'irnd' returns 2 or 5, then your computer is
+                If ``irnd`` returns 2 or 5, then your computer is
                 compilant with the IEEE standard for rounding. If it
                 returns 1 or 4, then it is doing some kind of rounding,
-                but not the IEEE standard. If 'irnd' returns 0 or 3,
+                but not the IEEE standard. If ``irnd`` returns 0 or 3,
                 then it is truncating the result, not rounding it.
 
-    'ngrd'   -- Is the number of ''guard digits'' used when truncating
+    ``ngrd``   -- Is the number of *guard digits* used when truncating
                 the ploduct of two mantissas to fit the representation
 
 This is taken from "NUMERICAL RECIPES in C", second edition,
@@ -87,7 +89,7 @@ Reprinted 1996.
     one = float(1)
     two = one + one
     zero = one - one
-    # Determine 'ibeta' and 'beta' by the method of M. Malcom.
+    # Determine ``ibeta`` and ``beta`` by the method of M. Malcom.
     a = temp1 = one
     while temp1 - one == zero:
         a += a
@@ -101,7 +103,7 @@ Reprinted 1996.
         itemp = int(temp - a)
     ibeta = itemp
     beta = float(ibeta)
-    # Determine 'it' and 'irnd'.
+    # Determine ``it`` and ``irnd``.
     it = 0
     b = temp1 = one
     while temp1 - one == zero:
@@ -118,7 +120,7 @@ Reprinted 1996.
     temp = tempa + betah
     if irnd == 0 and temp - tempa != zero:
         irnd = 2
-    # Determine 'negep' und 'epsneg'.
+    # Determine ``negep`` und ``epsneg``.
     negep = it + 3
     betain = one / beta
     a = one
@@ -135,7 +137,7 @@ Reprinted 1996.
         negep = negep - 1
     negep = -negep
     epsneg = a
-    # Determine 'machdep' and 'eps'.
+    # Determine ``machdep`` and ``eps``.
     machdep = -it - 3
     a = b
     while 1:
@@ -145,12 +147,12 @@ Reprinted 1996.
         a = a * beta
         machdep = machdep + 1
     eps = a
-    # Deterrmine 'ngrd'.
+    # Deterrmine ``ngrd``.
     ngrd = 0
     temp = one + eps
     if irnd == 0 and temp * one - one != zero:
         ngrd = 1
-    # Determine 'iexp'.
+    # Determine ``iexp``.
     i = 0
     k = 1
     z = betain
@@ -178,7 +180,7 @@ Reprinted 1996.
             iz = ibeta * iz
             iexp = iexp + 1
         mx = iz + iz - 1
-    # To determine 'minexp' and 'xmin', loop until an underflow
+    # To determine ``minexp`` and ``xmin``, loop until an underflow
     # occurs, then exit.
     while 1:
         xmin = y
@@ -200,7 +202,7 @@ Reprinted 1996.
         mx = mx + mx
         iexp = iexp + 1
     maxexp = mx + minexp
-    irnd = nxres + irnd  # Adjust 'irnd' to reflect partial underflow
+    irnd = nxres + irnd  # Adjust ``irnd`` to reflect partial underflow
     if irnd >= 2:
         maxexp = maxexp - 2  # Adjust for IEEE-stype machines
     i = maxexp + minexp
@@ -243,103 +245,65 @@ Reprinted 1996.
 
 __tmp = machar()
 
-# 'ibeta' is the radix in which numbers are represented, almost always
+# ``ibeta`` is the radix in which numbers are represented, almost always
 # 2, but occasionally 16, or even 10
 ibeta = __tmp["ibeta"]
 
-# 'it' is The number of base-'ibeta' digits in the floating point
+# ``it`` is The number of base-``ibeta`` digits in the floating point
 # mantissa
 it = __tmp["it"]
 
-# 'machep' is the exponent of the smallest (mos negative) power if
-# 'ibeta' that, added to 1.0 gives something different from 1.0.
+# ``machep`` is the exponent of the smallest (mos negative) power if
+# ``ibeta`` that, added to 1.0 gives something different from 1.0.
 machdep = __tmp["machdep"]
 
-# 'eps' is the floating-point number 'ibeta'**'machdep', loosly
-# referred to as the ''floating-point precision.''
+# ``eps`` is the floating-point number ``ibeta`` ** ``machdep``, loosly
+# referred to as the *floating-point precision*.
 eps = __tmp["eps"]
 
-# 'negep' is the exponenet of the smalles power of 'ibeta' that,
+# ``negep`` is the exponenet of the smalles power of ``ibeta`` that,
 # subtracted from 1.0, gives something different from 1.0.
 negep = __tmp["negep"]
 
-# 'epsneg' is 'ibeta'**'negep', another way of defining floating-point
-# precision. Not infrequently 'epsneg' is 0.5 times 'eps';
-# occasionally 'eps' and 'epsneg' are equal.
+# ``epsneg`` is ``ibeta`` ** ``negep``, another way of defining floating-point
+# precision. Not infrequently ``epsneg`` is 0.5 times ``eps``;
+# occasionally ``eps`` and ``epsneg`` are equal.
 epsneg = __tmp["epsneg"]
 
-# 'iexp' is the number of bits in the exponent (including its sign or
+# ``iexp`` is the number of bits in the exponent (including its sign or
 # bias)
 iexp = __tmp["iexp"]
 
-# 'minexp' is the smallest (most negative) power if 'ibeta' consistent
+# ``minexp`` is the smallest (most negative) power if ``ibeta`` consistent
 # with there no leading zeros in the mantissa.
 minexp = __tmp["minexp"]
 
-# 'xmin' is the floating-point number 'ibeta'**'minexp', generally the
+# ``xmin`` is the floating-point number ``ibeta`` ** ``minexp``, generally the
 # smallest (in magnitude) usable floating value
 xmin = __tmp["xmin"]
 
-# 'maxexp' is the smallest (positive) power of 'ibeta' that causes
+# ``maxexp`` is the smallest (positive) power of ``ibeta`` that causes
 # overflow.
 maxexp = __tmp["maxexp"]
 
-# 'xmax' Is (1-'epsneg')x'ibeta'**'maxexp', generally the largest (in
+# ``xmax`` Is (1-``epsneg``) x ``ibeta`` ** ``maxexp``, generally the largest (in
 # magnitude) usable floating value.
 xmax = __tmp["xmax"]
 
 # Returns a code in the range 0...5, giving information on what kind
 # of rounding is done in addition, and on how underflow is handled.
 #
-# If 'irnd' returns 2 or 5, then your computer is compilant with the
+# If ``irnd`` returns 2 or 5, then your computer is compilant with the
 # IEEE standard for rounding. If it returns 1 or 4, then it is doing
-# some kind of rounding, but not the IEEE standard. If 'irnd' returns
+# some kind of rounding, but not the IEEE standard. If ``irnd`` returns
 # 0 or 3, then it is truncating the result, not rounding it.
 irnd = __tmp["irnd"]
 
-# 'ngrd' is the number of ''guard digits'' used when truncating the
+# ``ngrd`` is the number of *guard digits* used when truncating the
 # ploduct of two mantissas to fit the representation
 ngrd = __tmp["ngrd"]
 
 
-def tst():
-    print(machar())
-    print(
-        """
-ibeta  : {ibeta:12d},
-it     : {it:12d},
-irnd   : {irnd:12d},
-ngrd   : {ngrd:12d},
-machdep: {machdep:12d},
-negep  : {negep:12d},
-iexp   : {iexp:12d},
-minexp : {minexp:12d},
-maxexp : {maxexp:12d},
-eps    : {eps:.10e},
-epsneg : {epsneg:.10e},
-xmin   : {xmin:.10e},
-xmax   : {xmax:.10e}""".format(
-            **machar()
-        )
-    )
-
-
-if __name__ == "__main__":
-    import profile
-
-    profile.run("tst()", "machar.stat")
-
-    import pstats
-
-    p = pstats.Stats("machar.stat")
-    # p.strip_dirs().sort_stats(-1).print_stats()
-    # p.sort_stats('name')
-    # p.print_stats()
-    # p.sort_stats('cumulative').print_stats(10)
-    p.sort_stats("time").print_stats(10)
-    # p.sort_stats('calls').print_stats(10)
-
-
 # Local Variables:
 # mode: python
 # compile-command: "python ../../setup.py test"
